/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
var app = {
    "appurl": "http://app.vertalen.nu",
    "online": false,
    "app_loaded": false,
    // Application Constructor
    initialize: function() {
        $(document).ready( function() {
            console.log('JQ finished loading');
            var deviceReadyDeferred = jQuery.Deferred();
            var jqmReadyDeferred    = jQuery.Deferred();
            document.addEventListener("online", app.onlineEvent, false);
            document.addEventListener("deviceready", function () {
                console.log("PhoneGap finished loading");
                app.onDeviceReady();
                deviceReadyDeferred.resolve();
            }, false);

            jQuery(document).one("pageinit", function () {
                console.log("jQuery.Mobile finished loading");
                jqmReadyDeferred.resolve();
            });

            jQuery.when(deviceReadyDeferred, jqmReadyDeferred).then(function () {
                console.log("PhoneGap & jQuery.Mobile finished loading");
                app.initApp();
                app.app_loaded = true;
                console.log("App finished loading");
            });
        });    
    },
    
    // deviceready Event Handler
    //
    // The scope of 'this' is the event. In order to call the 'receivedEvent'
    // function, we must explicity call 'app.receivedEvent(...);'
    onDeviceReady: function() {
        app.receivedEvent('deviceready');                 
        if(can_play_audio()) $('body').addClass('audiosupported');   
        $('#start-logo').on('click', this.initApp);                          
    },
    initApp: function() {   
        navigator.splashscreen.hide();     
        app.checkNetwork();        
        if(app.online) {                    
            $.mobile.changePage(app.appurl, { allowSamePageTransition: true, transition: "none", changeHash: false });           
        }    
        else {            
            $('.event').hide();
            $('.event.offline').show();
        }          
         // Prevent going back to index loader
        $(document).on('pagebeforechange', function(event, data) {
          //console.log(data);
          if (typeof data.toPage === 'string' && data.options.direction == 'back') {
            var uri =  $.mobile.path.parseUrl(data.toPage);
            if(uri.filename == 'index.html') {
              //console.log(uri.filename);
              data.toPage = app.appurl;
            } 
          }  
        });   
        $(document).on("swipeleft", function () {
            window.history.forward();        
        });
        $(document).on("swiperight", function () {     
            window.history.back();        
        });                    
    },
    // Update DOM on a Received Event
    receivedEvent: function(id) {
        var parentElement = document.getElementById(id);
        var listeningElement = parentElement.querySelector('.listening');
        var receivedElement = parentElement.querySelector('.received');

        listeningElement.setAttribute('style', 'display:none;');
        receivedElement.setAttribute('style', 'display:block;');        
    },
    isOnline: function() {
        return app.online;
    },   
    checkNetwork: function() {        
        if(navigator.connection.type == Connection.NONE) app.online = false;
        else app.online = true;                
    }, 
    onlineEvent: function() {      
        if(app.online == false && app.app_loaded) {
            app.online = true;
            app.initApp();
        }        
        app.online = true;
        console.log('went online');
    }
};

function switch_languages(fromlang, tolang) {
    var fromLangId = $('.ui-page-active #'+fromlang).val();
    var toLangId = $('.ui-page-active #'+tolang).val();
    $('.ui-page-active #'+fromlang).val(toLangId);
    $('.ui-page-active #'+tolang).val(fromLangId);
    $('.ui-page-active #'+fromlang).selectmenu("refresh");
    $('.ui-page-active #'+tolang).selectmenu("refresh");
}

function play_audio(sound) {    
    if (window.HTMLAudioElement) {
        var snd = new Audio('');        
        if(snd.canPlayType('audio/mp3')) {
            snd = new Audio(sound);
        }       
        snd.play();
    }
    else {
        // Silently fail
    }
}
        
function can_play_audio() {
    // Check HTML5 audio support
    var a = document.createElement('audio');
    return !!(a.canPlayType && a.canPlayType('audio/mpeg;').replace(/no/, ''));
}   

/**
 * Simple localStorage with Cookie Fallback
 *
 * USAGE:
 * ----------------------------------------
 * Set New / Modify:
 *   store('my_key', 'some_value');
 *
 * Retrieve:
 *   store('my_key');
 *
 * Delete / Remove:
 *   store('my_key', null);
 */
 
function lsSupport() {
    // Check for native support
    if (localStorage) return true;
    else return false;    
}

function set_key(key, value) {
    var lsSupport = lsSupport();
        
    // If value is detected, set new or modify store
    if (typeof value !== "undefined" && value !== null) {
        if (lsSupport) { // Native support
            localStorage.setItem(key, value);
        } else { // Use Cookie
            createCookie(key, value, 30);
        }
    }
    
       // Null specified, remove store
    if (value === null) {
        if (lsSupport) { // Native support
            localStorage.removeItem(key);
        } else { // Use cookie
            createCookie(key, '', -1);
        }
    }
}
  
function get_key(key) {
    if (lsSupport()) { // Native support
        return localStorage.getItem(key);
    } else { // Use cookie 
        return readCookie(key);
    }
}    

/**
 * Creates new cookie or removes cookie with negative expiration
 * @param  key       The key or identifier for the store
 * @param  value     Contents of the store
 * @param  exp       Expiration - creation defaults to 30 days
 */

function createCookie(key, value, exp) {
    var date = new Date();
    date.setTime(date.getTime() + (exp * 24 * 60 * 60 * 1000));
    var expires = "; expires=" + date.toGMTString();
    document.cookie = key + "=" + value + expires + "; path=/";
}

/**
 * Returns contents of cookie
 * @param  key       The key or identifier for the store
 */

function readCookie(key) {
    var nameEQ = key + "=";
    var ca = document.cookie.split(';');
    for (var i = 0, max = ca.length; i < max; i++) {
        var c = ca[i];
        while (c.charAt(0) === ' ') c = c.substring(1, c.length);
        if (c.indexOf(nameEQ) === 0) return c.substring(nameEQ.length, c.length);
    }
    return null;
}